@@ -35,20 +35,6 @@
 #include <libdivecomputer/descriptor.h>
 #include <libdivecomputer/parser.h>
 
-#include <libdivecomputer/suunto.h>
-#include <libdivecomputer/reefnet.h>
-#include <libdivecomputer/uwatec.h>
-#include <libdivecomputer/oceanic.h>
-#include <libdivecomputer/mares.h>
-#include <libdivecomputer/hw.h>
-#include <libdivecomputer/cressi.h>
-#include <libdivecomputer/zeagle.h>
-#include <libdivecomputer/atomics.h>
-#include <libdivecomputer/shearwater.h>
-#include <libdivecomputer/diverite.h>
-#include <libdivecomputer/citizen.h>
-#include <libdivecomputer/divesystem.h>
-
 #include "dctool.h"
 #include "output.h"
 #include "common.h"
@@ -166,7 +152,7 @@ dctool_parse_run (int argc, char *argv[], dc_context_t *context, dc_descriptor_t
 		goto cleanup;
 	}
 
-	for (unsigned int i = 0; i < argc; ++i) {
+	for (int i = 0; i < argc; ++i) {
 		// Read the input file.
 		buffer = dctool_file_read (argv[i]);
 		if (buffer == NULL) {
