@@ -52,6 +52,9 @@ array_convert_hex2bin (const unsigned char input[], unsigned int isize, unsigned
 unsigned int
 array_convert_str2num (const unsigned char data[], unsigned int size);
 
+unsigned int
+array_convert_bcd2dec (const unsigned char data[], unsigned int size);
+
 unsigned int
 array_uint_be (const unsigned char data[], unsigned int n);
 
@@ -64,6 +67,9 @@ array_uint32_be (const unsigned char data[]);
 unsigned int
 array_uint32_le (const unsigned char data[]);
 
+unsigned int
+array_uint32_word_be (const unsigned char data[]);
+
 void
 array_uint32_le_set (unsigned char data[], const unsigned int input);
 
