@@ -60,6 +60,7 @@
 #include "mclean_extreme.h"
 #include "liquivision_lynx.h"
 #include "sporasub_sp2.h"
+#include "deepsix_excursion.h"
 
 // Not merged upstream yet
 #include "garmin.h"
@@ -228,6 +229,9 @@ dc_device_open (dc_device_t **out, dc_context_t *context, dc_descriptor_t *descr
 	case DC_FAMILY_SPORASUB_SP2:
 		rc = sporasub_sp2_device_open (&device, context, iostream);
 		break;
+	case DC_FAMILY_DEEPSIX_EXCURSION:
+		rc = deepsix_excursion_device_open (&device, context, iostream);
+		break;
 	default:
 		return DC_STATUS_INVALIDARGS;
 
