@@ -60,6 +60,7 @@
 #include "mclean_extreme.h"
 #include "liquivision_lynx.h"
 #include "sporasub_sp2.h"
+#include "deepsix_excursion.h"
 
 // Not merged upstream yet
 #include "garmin.h"
@@ -189,6 +190,9 @@ dc_parser_new_internal (dc_parser_t **out, dc_context_t *context, dc_family_t fa
 	case DC_FAMILY_SPORASUB_SP2:
 		rc = sporasub_sp2_parser_create (&parser, context);
 		break;
+	case DC_FAMILY_DEEPSIX_EXCURSION:
+		rc = deepsix_excursion_parser_create (&parser, context);
+		break;
 	default:
 		return DC_STATUS_INVALIDARGS;
 
